==> nextcloud-18.0.4.tgz: nextcloud/apps/theming/l10n/ar.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "جار تحميل المعاينة ...",
    "Saved" : "تم الحفظ",
    "Admin" : "ادارة",
    "a safe home for all your data" : "مكان آمن لكل معلوماتك",
    "The given name is too long" : "هذا الاسم أطول مما يجب",
    "The given web address is too long" : "هذا العنوان أطول مما يجب",
    "The given slogan is too long" : "هذا الشعار أطول مما يجب",
    "The given color is invalid" : "هناك خطأ في اللون",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم الملف الذي تريد ترفيعه أعلى مما MAX_FILE_SIZE يسمح به في واجهة ال HTML.",
    "No file was uploaded" : "لم يتم رفع أي ملف",
    "Missing a temporary folder" : "المجلد المؤقت غير موجود",
    "No file uploaded" : "لم يتم رفع الملف",
    "Unsupported image type" : "صيغة الصورة غير مقبولة",
    "Theming" : "تخصيص القالب",
    "Privacy policy" : "سياسة الخصوصية",
    "Open documentation" : "فتح الدليل",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "السمات تجعل من الممكن بسهولة تخصيص الشكل والمظهر لنموذجك ودعم العملاء. سيكون هذا مرئيا لجميع المستخدمين.",
    "Name" : "الاسم",
    "Reset to default" : "اعادة تعيين الافتراضيات",
    "Slogan" : "شعار",
    "Color" : "لون",
    "Logo" : "العلامة",
    "Upload new logo" : "رفع شعار جديد",
    "Login image" : "صورة الدخول",
    "Upload new login background" : "تحميل خلفية جديدة للدخول",
    "Remove background image" : "إزالة صورة الخلفية",
    "Advanced options" : "الخيارات المتقدمة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-18.0.6.tgz: nextcloud/apps/theming/l10n/ar.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "جار تحميل المعاينة ...",
    "Saved" : "تم الحفظ",
    "Admin" : "ادارة",
    "a safe home for all your data" : "مكان آمن لكل معلوماتك",
    "The given name is too long" : "هذا الاسم أطول مما يجب",
    "The given web address is too long" : "هذا العنوان أطول مما يجب",
    "The given slogan is too long" : "هذا الشعار أطول مما يجب",
    "The given color is invalid" : "هناك خطأ في اللون",
    "The file was uploaded" : "الملف تم رفعه",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم الملف الذي تريد ترفيعه أعلى مما MAX_FILE_SIZE يسمح به في واجهة ال HTML.",
    "The file was only partially uploaded" : "الملف قد رُفع جزءا منه فقط",
    "No file was uploaded" : "لم يتم رفع أي ملف",
    "Missing a temporary folder" : "المجلد المؤقت غير موجود",
    "Could not write file to disk" : "لم يستطع كتابة ملف للقرص",
    "A PHP extension stopped the file upload" : "اضافة البي اچ بي PHP اوقفت رفع الملف",
    "No file uploaded" : "لم يتم رفع الملف",
    "Unsupported image type" : "صيغة الصورة غير مقبولة",
    "Theming" : "تخصيص القالب",
    "Privacy policy" : "سياسة الخصوصية",
    "Open documentation" : "فتح الدليل",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "السمات تجعل من الممكن بسهولة تخصيص الشكل والمظهر لنموذجك ودعم العملاء. سيكون هذا مرئيا لجميع المستخدمين.",
    "Name" : "الاسم",
    "Reset to default" : "اعادة تعيين الافتراضيات",
    "Web link" : "رابط الويب",
    "Slogan" : "شعار",
    "Color" : "لون",
    "Logo" : "العلامة",
    "Upload new logo" : "رفع شعار جديد",
    "Login image" : "صورة الدخول",
    "Upload new login background" : "تحميل خلفية جديدة للدخول",
    "Remove background image" : "إزالة صورة الخلفية",
    "Advanced options" : "الخيارات المتقدمة",
    "Legal notice link" : "رابط الإشعار القانوني",
    "Privacy policy link" : "رابط سياسة الخصوصية",
    "Header logo" : "شعار الرأسية",
    "Upload new header logo" : "تحميل شعار رأسية جديد",
    "Favicon" : "الأيقونة المفضلة",
    "Upload new favicon" : "تحميل أيقونة مفضلة جديدة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
